@@ -5,6 +5,9 @@ __all__ = [
     "napari_write_labels",
     "napari_write_points",
     "napari_write_shapes",
+    "generate_tmap_config",
+    "generate_shapes_dict",
+    "tmap_writer"
 ]
 
 from ._writer import (
@@ -14,3 +17,10 @@ from ._writer import (
     napari_write_points,
     napari_write_shapes,
 )
+
+from .convert import (
+    generate_tmap_config,
+    generate_shapes_dict,
+    tmap_writer
+)
+
